# Keys for the JSON parameter file
NAME = 'name'
TYPE = 'type'
VALUES = 'possible_values'
DESCRIPTION = 'description'
USAGE = 'usage'
DEFAULT = 'default_value'
DEVELOPMENT = 'development'
EXCLUDE_APPS = 'exclude_apps' # possibilities see below

# Used types
TYPE_STRING = 'string'
TYPE_INT = 'int'
TYPE_FLOAT = 'float'
TYPE_BOOL = 'bool'
TYPE_LIST_STRING = 'list<string>'

# Exclude Apps
EXCLUDE_AUGUSTUS = 'augustus'
EXCLUDE_ETRAINING = 'etraining'
EXCLUDE_PYGUSTUS = 'pygustus'
